===============================
Montague-PasteDeploy
===============================

.. image:: http://img.shields.io/travis/inklesspen/montague_pastedeploy/master.png?style=flat
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/inklesspen/montague_pastedeploy

.. image:: https://ci.appveyor.com/api/projects/status/github/inklesspen/montague_pastedeploy?branch=master
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/inklesspen/montague_pastedeploy

.. image:: http://img.shields.io/coveralls/inklesspen/montague_pastedeploy/master.png?style=flat
    :alt: Coverage Status
    :target: https://coveralls.io/r/inklesspen/montague_pastedeploy

.. image:: http://img.shields.io/pypi/v/montague_pastedeploy.png?style=flat
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/montague_pastedeploy

.. image:: http://img.shields.io/pypi/dm/montague_pastedeploy.png?style=flat
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/montague_pastedeploy

.. image:: https://landscape.io/github/inklesspen/montague_pastedeploy/master/landscape.png?style=flat
    :target: https://landscape.io/github/inklesspen/montague_pastedeploy/master
    :alt: Code Quality Status

.. image:: https://readthedocs.org/projects/montague_pastedeploy/badge/?style=flat
    :target: https://readthedocs.org/projects/montague_pastedeploy
    :alt: Documentation Status

Montague-PasteDeploy is a loader for Montague with full PasteDeploy_ backwards compatibility.
          
* Free software: MIT license

Status
======

Montague-PasteDeploy is a pre-1.0 project using Semantic Versioning.

Installation
============

::

    pip install montague_pastedeploy

Documentation
=============

https://montague_pastedeploy.readthedocs.org/

Development
===========

To run the all tests run::

    tox


.. _PasteDeploy: http://pythonpaste.org/deploy/
